summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoMainWindow.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /lib/kofficecore/KoMainWindow.cpp
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficecore/KoMainWindow.cpp')
-rw-r--r--lib/kofficecore/KoMainWindow.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/kofficecore/KoMainWindow.cpp b/lib/kofficecore/KoMainWindow.cpp
index 4e30d64a..5e4567de 100644
--- a/lib/kofficecore/KoMainWindow.cpp
+++ b/lib/kofficecore/KoMainWindow.cpp
@@ -63,15 +63,15 @@
class KoPartManager : public KParts::PartManager
{
public:
- KoPartManager( TQWidget * tqparent, const char * name = 0L )
- : KParts::PartManager( tqparent, name )
+ KoPartManager( TQWidget * parent, const char * name = 0L )
+ : KParts::PartManager( parent, name )
{
setSelectionPolicy( KParts::PartManager::TriState );
setAllowNestedParts( true );
setIgnoreScrollBars( true );
// Allow right-click on embedded objects (without activating them)
// But beware: this means right-click on tqparent, from embedded object,
// doesn't make the tqparent active first...
setActivationButtonMask( Qt::LeftButton | Qt::MidButton );
}
virtual bool eventFilter( TQObject *obj, TQEvent *ev )
@@ -63,15 +63,15 @@
setIgnoreScrollBars( true );
// Allow right-click on embedded objects (without activating them)
- // But beware: this means right-click on tqparent, from embedded object,
- // doesn't make the tqparent active first...
+ // But beware: this means right-click on parent, from embedded object,
+ // doesn't make the parent active first...
setActivationButtonMask( Qt::LeftButton | Qt::MidButton );
}